@@ -126,27 +126,27 @@ def WriteBin( iqData, fSamplingRate, FileName):
     """Writes a bin file, e.g. for use on KS generators
     iqData can be a list of complex or list of floats (iqiqiq format mandatory).
     writtenSamples = WriteBin("MyFile.bin",complexList, fs)"""
-    
+
     import struct
     from datetime import date
     import math
     import logging
-    
+
     #check if iqData is complex
     if isinstance( iqData[0], complex):
         iqData = Complex2Iqiq( iqData)
-        
+
     NumberOfSamples = len(iqData) // 2
-         
+  
     #Find maximum magnitude and scale for max to be FullScale (1.0)
     power = []
     for n in range(NumberOfSamples):
         power.append(abs(iqData[2*n]**2 + iqData[2*n+1]**2))
     scaling = math.sqrt( max(power))
-    
+
     # normalize to magnitude 1
     iqData = [ iq / scaling for iq in iqData]
-    
+
     #calculate rms in dB (below full scale)
     rms = math.sqrt(sum(power)/NumberOfSamples)/scaling
     rms = abs(20*math.log10( rms))
@@ -265,22 +265,23 @@ def ReadWv( FileName, ReadData = True):
     if (Counter > len(data)) & (binaryStart == 0):
         logging.warning( "Required tags not found, potentially incompatible file format!")
 
-    res = re.search("SAMPLES[ ]*:[ ]*(?P<NumberOfSamples>[0-9]*)",tags)
+    res = re.search("SAMPLES[ ]*:[ ]*(?P<NumberOfSamples>[0-9]*)[ ]*}",tags)
     if res:
         NumberOfSamples = int( res.group("NumberOfSamples"))
     else:
         NumberOfSamples = NaN
-    res = re.search("CLOCK[ ]*:[ ]*(?P<SamplingRate>[0-9]*.[0-9]*[eE]?[+\-]?[0-9]*)",tags)
+    # res = re.search("CLOCK[ ]*:[ ]*(?P<SamplingRate>[0-9]*.[0-9]*[eE]?[+\-]?[0-9]*)",tags)
+    res = re.search("CLOCK[ ]*:[ ]*(?P<SamplingRate>[0-9]*.[0-9]*[eE]?[+\-]?[0-9]*)[ ]*}",tags)
     if res:
         SamplingRate = float( res.group("SamplingRate"))
     else:
         SamplingRate = NaN
-    res = re.search("LEVEL OFFS[ ]*:[ ]*(?P<RMSLevelOffset>[0-9]*.[0-9]*)",tags)
+    res = re.search("LEVEL OFFS[ ]*:[ ]*(?P<RMSLevelOffset>[0-9]*.[0-9]*)[ ]*}",tags)
     if res:
         RmsLevelOffset = float( res.group("RMSLevelOffset"))
     else:
         RmsLevelOffset = NaN
-    res = re.search("COMMENT:Signal generated for SMx RMS level[ ]*:[ ]*(?P<RfRmsLevel>[0-9]*.[0-9]*)",tags)
+    res = re.search("COMMENT:Signal generated for SMx RMS level[ ]*:[ ]*(?P<RfRmsLevel>[0-9]*.[0-9]*)[ ]*}",tags)
     if res:
         RfRmsLevel = float( res.group("RfRmsLevel"))
     else:
@@ -495,7 +496,7 @@ def Iqw2Iqtar( FileName, fs, keepIqw = False, fCenterFrequency = 0):
         os.remove( os.path.join(path, xmlfile))
     except:
         logging.error("IqTar (" + FileName +") write error!" )
-    
+
     return os.path.join(path, iqtarfile)
 
 
@@ -505,7 +506,7 @@ def Iqw2Wv( FileName, fs, keepIqw = False):
     binary data from instrument into file (iqw).
     Note: iqw must be in iqiqiq format
     writtenSamples = WriteIqTar(iqList,fs,"MyFile.iq.tar")"""
-    
+
     import os
     import tarfile
     import re
@@ -514,16 +515,16 @@ def Iqw2Wv( FileName, fs, keepIqw = False):
     import math
     import struct
     from datetime import date
-    
+
     NumberOfSamples = 0
     BytesPerValue = 4
     BlockSize = 10000
-    
+
     if os.path.isfile( FileName):
         NumberOfSamples = os.stat( FileName).st_size // (BytesPerValue * 2)
     else:
         logging.error("File "+ FileName+" does not exist!")
-    
+
     #path,filename = os.path.split(FileName)
     wvfile = re.sub( "iqw", "wv", FileName, flags=re.IGNORECASE)
 
@@ -566,7 +567,7 @@ def Iqw2Wv( FileName, fs, keepIqw = False):
         fileout.write( ("{LEVEL OFFS:" +  "{:2.4f}".format(-1*rmsvalue) + "," + "{:2.4f}".format(maxvalue) + "}").encode("ASCII"))
         fileout.write( ("{SAMPLES:" + str(NumberOfSamples) + "}").encode("ASCII"))
         fileout.write( ("{WAVEFORM-" +  str(4*NumberOfSamples+1) + ": #").encode("ASCII"))
-        
+
         # now copy data from iqw to wv
         ReadCounter = 0
         while ReadCounter<NumberOfSamples:
@@ -578,11 +579,11 @@ def Iqw2Wv( FileName, fs, keepIqw = False):
             # Convert to int16, use floor function, otherwise distribution is not correct
             data = [ math.floor(iq * 32767 +.5) for iq in data]
             fileout.write( struct.pack("h"*len(data),*data))
-            
+  
         fileout.write( "}".encode("ASCII"))
         fileout.close()
         file.close()
-        
+
         # remove iqw
         os.remove( FileName)
     except:
@@ -592,4 +593,4 @@ def Iqw2Wv( FileName, fs, keepIqw = False):
 
 if __name__ == "__main__":
     # execute only if run as a script
-    pass   
+    pass
